@@ -8,7 +8,7 @@ use Mojolicious::Plugin::OpenAPI::Parameters;
 
 use constant DEBUG => $ENV{MOJO_OPENAPI_DEBUG} || 0;
 
-our $VERSION = '5.04';
+our $VERSION = '5.05';
 
 has route     => sub {undef};
 has validator => sub { JSON::Validator::Schema->new; };
@@ -326,7 +326,7 @@ Mojolicious::Plugin::OpenAPI - OpenAPI / Swagger plugin for Mojolicious
   }, "echo";
 
   # Load specification and start web server
-  plugin OpenAPI => {url => "data:///swagger.json"};
+  plugin OpenAPI => {url => "data:///swagger.yaml"};
   app->start;
 
   __DATA__
@@ -620,7 +620,7 @@ Plugin for handling security definitions in your schema.
 
 =item * L<Mojolicious::Plugin::OpenAPI::SpecRenderer>
 
-Plugin for exposing your spec in human readble or JSON format.
+Plugin for exposing your spec in human readable or JSON format.
 
 =item * L<https://www.openapis.org/>
 
